==> qcad-3.15.5.3.tgz: lib/qcad/ts/qcadgui_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Неверный</translation>
    </message>
</context>
</TS>

==> qcad-3.23.0.0.tgz: lib/qcad/ts/qcadgui_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Сетка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>На объекте</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикуляр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Тангенциальный</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Средний</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Пересечение</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Ссылка</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+172"/>
        <source>Invalid</source>
        <translation>Неверный</translation>
    </message>
</context>
</TS>
